import { AsyncStorage } from "react-native";
import { AsyncStorageKeys } from "./Enums";

export default class AuthHelper {

    storeAuthData = async(authTokenData) => {
        try {
            await AsyncStorage.multiSet([[AsyncStorageKeys.AUTH_TOKEN, `${authTokenData.access}`], [AsyncStorageKeys.REFRESH_TOKEN, `${authTokenData.refresh}`], [AsyncStorageKeys.USER_ID, `${authTokenData.userId}`]]);
        } catch (error) {
            //TODO - Firebase Event
        }
    };

    storeUser = async(user) => {
        try {
            await AsyncStorage.setItem(AsyncStorageKeys.USER, JSON.stringify(user));
        } catch (error) {
            //TODO - Firebase Event
        }
    };

    getStorageValue = async (key) => {
        try {
            const token = await AsyncStorage.getItem(key);

            if(token != null) {
                return token;
            }
        } catch(error) {
            //TODO - Firebase Event
        }
    };

    getAuthTokenPromise = () => {
        return this.getStorageValue(AsyncStorageKeys.AUTH_TOKEN);
    };

    getRefreshTokenPromise = () => {
        return this.getStorageValue(AsyncStorageKeys.REFRESH_TOKEN);
    };

    getUserIdPromise = () => {
        return this.getStorageValue(AsyncStorageKeys.USER_ID);
    };

    getUserPromise = () => {
        let userPromise = this.getStorageValue(AsyncStorageKeys.USER);

        return userPromise.then((user) => {
            if(user != null)
                return JSON.parse(user);

            return null;
        });
    };

    isAuthorizedPromise = () => {
        return this.getAuthTokenPromise().then((token) => {
            return token != null;
        }).catch(() => {
            return false;
        });
    };

    clearAuthData = async () => {
        try {
            await AsyncStorage.clear();
        } catch (error) {
            //TODO - Firebase Event
        }
    };
}
