//Worksmith standard colors
import {ValueIsSet} from "../index";

export const Color = Object.freeze({
    RED: '#DD2E2B',
    ORANGE: '#F78B21',
    GREEN: '#6DAD3D',
    TURQUOISE: '#156F83',
    BLUE: '#3F7BBF',
    NAVY: '#293D4B',
    BLACK: '#171616',
    DARK_GREY: '#3D3D3D',
    BORDER_GREY: '#979797',
    MEDIUM_GREY: '#B2B2B2',
    GREY: '#D9D9D9',
    OFF_WHITE: '#F8F8F8',
    WHITE: '#FFFFFF',
    TRANSPARENT: 'transparent'
});

//Routing strings for all pages in the app
export const LoggedOutRoutes = Object.freeze({
   LOGIN: '/',
   RESET_PASSWORD: '/ResetPassword',
   CHECK_EMAIL: '/CheckEmail'
});

export const VendorRoutes = Object.freeze({
    NEW_OPPORTUNITIES: '/',
    IN_PROGRESS_OPPORTUNITIES: '/InProgressOpportunities',
    COMPLETED_JOBS: (payableId) => ValueIsSet(payableId) ? '/Completed/' + payableId : '/Completed',
    JOB_DETAILS: (obligationId) => ValueIsSet(obligationId) ? '/JobDetails/' + obligationId : '/JobDetails',
    RECURRING_SCHEDULE_CHANGES: '/RecurringScheduleChanges',
    REQUEST_JOB_SCHEDULE_CHANGE: (obligationId) => ValueIsSet(obligationId) ? '/RequestJobScheduleChange/' + obligationId : '/RequestJobScheduleChange',
    RESCHEDULE_CHANGE_REQUEST: (changeRequestId) => ValueIsSet(changeRequestId) ? '/RescheduleChangeRequest/' + changeRequestId : '/RescheduleChangeRequest',
    RESCHEDULE_BID_REQUEST: (opportunityId) => ValueIsSet(opportunityId) ? '/RescheduleBid/' + opportunityId : '/RescheduleBid',
    RESCHEDULE_WALKTHROUGH_REQUEST: (opportunityId) => ValueIsSet(opportunityId) ? '/RescheduleWalkthrough/' + opportunityId : '/RescheduleWalkthrough',
    REVIEW_SUBMITTED_CHANGE_REQUEST: (changeRequestId) => ValueIsSet(changeRequestId) ? '/ReviewSubmittedChangeRequest/' + changeRequestId : '/ReviewSubmittedChangeRequest',
    PERIOD_SELECTION: '/PeriodSelection',
    OPPORTUNITY_DETAILS: (opportunityId) => ValueIsSet(opportunityId) ? '/Details/' + opportunityId : '/Details',
    OPPORTUNITY_COMMENTS: (opportunityId) => ValueIsSet(opportunityId) ? '/Comments/' + opportunityId : '/Comments',
    COMPLETE_JOB_FORM: (obligationId) => ValueIsSet(obligationId) ? '/CompleteJobForm/' + obligationId : '/CompleteJobForm',
    SCHEDULE_CHANGE: '/JobsToReschedule',
    PAST_DUE_JOBS: '/PastDueJobs',
    MY_SCHEDULE:'/MySchedule',
    FORM_PAGE: '/FormPage',
    CONTACT_SUPPORT: '/ContactSupport',
    BID_SUBMISSION: (opportunityId) => ValueIsSet(opportunityId) ? '/BidSubmission/' + opportunityId : '/BidSubmission',
    SCHEDULED_JOBS: '/ScheduledJobs',
    WALKTHROUGH_SUBMISSION: (opportunityId) => ValueIsSet(opportunityId) ? '/WalkthroughSubmission/' + opportunityId : '/WalkthroughSubmission'
});

export const ClientRoutes = Object.freeze({
    BID_DETAILS: (bidId) => ValueIsSet(bidId) ? '/BidDetails/' + bidId : '/BidDetails',
    BID_SELECTION: (requestId) => ValueIsSet(requestId) ? '/BidSelection/' + requestId : '/BidSelection',
    COMPLETED_JOBS_TO_RATE: '/CompletedJobsToRate', //LOCAL ONLY
    CONTACT_SUPPORT: '/ContactSupport',
    CORPORATE_REVIEW: '/RequestsInCorporateReview', //ADMIN ONLY
    DASHBOARD: '/',
    FEEDBACK_REQUEST_DETAILS: (feedbackRequestId) => ValueIsSet(feedbackRequestId) ? '/FeedbackRequestDetails/' + feedbackRequestId : '/FeedbackRequestDetails', //LOCAL ONLY
    JOBS_AND_WALKTHROUGHS: (date) => ValueIsSet(date) ? '/JobsAndWalkthroughs/' + date : '/JobsAndWalkthroughs', //ADMIN ONLY,
    JOB_DETAILS: (obligationId) => ValueIsSet(obligationId) ? '/JobDetails/' + obligationId : '/JobDetails',
    SCHEDULE_CHANGE: '/JobsToReschedule',
    JOBS_TO_SCHEDULE: '/JobsToSchedule',
    NEW_REQUEST: '/NewRequest',
    PENDING_BIDS: '/RequestsWithPendingBids',
    RECURRING_SCHEDULE_CHANGES: '/RecurringScheduleChanges',
    REQUEST_JOB_SCHEDULE_CHANGE: (obligationId) => ValueIsSet(obligationId) ? '/RequestJobScheduleChange/' + obligationId : '/RequestJobScheduleChange',
    REVIEW_CHANGE_REQUEST: (changeRequestId) => ValueIsSet(changeRequestId) ? '/ReviewChangeRequest/' + changeRequestId : '/ReviewChangeRequest',
    REVIEW_SUBMITTED_CHANGE_REQUEST: (changeRequestId) => ValueIsSet(changeRequestId) ? '/ReviewSubmittedChangeRequest/' + changeRequestId : '/ReviewSubmittedChangeRequest',
    REQUEST_COMMENTS: (requestId) => ValueIsSet(requestId) ? '/RequestComments/' + requestId : '/RequestComments',
    REQUEST_DETAILS: (requestId) => ValueIsSet(requestId) ? '/RequestDetails/' + requestId : '/RequestDetails',
    REQUEST_SUBMISSION: (serviceLineId) => ValueIsSet(serviceLineId) ? '/RequestSubmission/' + serviceLineId : '/RequestSubmission',
    WALKTHROUGH_SUBMITTED: '/RequestsWithSubmittedWalkthroughs',
    EMERGENCY: '/EmergencyRequests',
    OPEN_REQUEST_LOCATIONS: '/OpenRequestLocations',
    OPEN_REQUESTS: (locationId) => ValueIsSet(locationId) ? '/OpenRequests/' + locationId : '/OpenRequests',
    ACCEPT_AND_SCHEDULE_PROPOSAL: (proposalId, proposalType) => ValueIsSet(proposalId) ? '/AcceptAndScheduleProposal/' + proposalType + '/' + proposalId : '/AcceptAndScheduleProposal',
    SCHEDULE_PROPOSAL: (proposalId, proposalType) => ValueIsSet(proposalId) ? '/ScheduleProposal/' + proposalType + '/' + proposalId : '/ScheduleProposal',
    SCHEDULED_JOBS: '/ScheduledJobs',
    SERVICE_LINE_CATEGORY: (categoryId) => ValueIsSet(categoryId) ? '/ServiceLineCategory/' + categoryId : '/ServiceLineCategory',
    SERVICE_LINE_SEARCH: '/ServiceLineSearch',
    WALKTHROUGH_DETAILS: (walkthroughId) => ValueIsSet(walkthroughId) ? '/WalkthroughDetails/' + walkthroughId : '/WalkthroughDetails',
    UNREAD_MESSAGES: '/RequestsWithUnreadMessages',
    WALKTHROUGH_SELECTION: (requestId) => ValueIsSet(requestId) ? '/WalkthroughSelection/' + requestId : '/WalkthroughSelection',
    WALKTHROUGHS_TO_SCHEDULE: '/WalkthroughsToSchedule',
});

export const ClientUserRole = Object.freeze({
    ADMIN: 'Administrator',
    REGIONAL_MANAGER: 'Regional Manager',
    LOCATION_MANAGER: 'Location Manager'
});

export const ClientServiceLineConfigurationType = Object.freeze({
    ALL: "All",
    DRY_CLEANING_ONLY: "Dry Cleaning Only",
    NON_DRY_CLEANING_ONLY: "Non-dry cleaning only"
});

export const ProposalType = Object.freeze({
    BID: "bid",
    WALKTHROUGH: "Walkthrough"
});

export const BidPricingType = Object.freeze({
    LUMP_SUM: "lump sum",
    HOURLY: "hourly rate",
    ITEMIZED: "itemized"
});

export const RfpType = Object.freeze({
    ON_DEMAND: "on-demand",
    RECURRING: "recurring",
    PRICING_ONLY: "pricing-only"
});

export const RfpStatus = Object.freeze({
    NEW: "new",
    PENDING_ADMIN: "pending admin approval",
    PENDING_REGIONAL_MANAGER: "pending regional manager approval",
    PENDING_ADMIN_BID: "pending admin bid approval",
    PENDING_REGIONAL_MANAGER_BID: "pending regional manager bid approval",
    SOURCING: "sourcing",
    WALKTHROUGH_SCHEDULED: "walkthrough scheduled",
    NEEDS_CLIENT_INPUT: "needs client input",
    SCHEDULING: "scheduling",
    SCHEDULED: "scheduled",
    COMPLETED: "completed",
    CANCELED: "canceled"
});

export const ScheduleHandlerStatus = Object.freeze({
    OPEN: "OPEN",
    COMPLETED: "COMPLETED",
    CANCELED: "CANCELED"
});

export const WalkthroughStatus = Object.freeze({
    ACCEPTED: "accepted",
    NEEDS_CLIENT_INPUT: "needs client input",
    CANCELED: "canceled",
    DECLINED: "declined",
});

export const BidStatus = Object.freeze({
    ACCEPTED: "accepted",
    REJECTED: "rejected",
    CANCELED: "canceled",
    PENDING_ADMIN: "pending admin approval",
    PENDING_REGIONAL_MANAGER: "pending regional manager approval",
    NEEDS_CLIENT_INPUT: "needs client input",
    NEEDS_VENDOR_INPUT: "needs vendor input"
});

export const AttachmentType = Object.freeze({
    COMPLETION_PHOTO: "Completion Photo",
    REPORTING_FORM: "Reporting Form",
    RECEIPT: "Receipt",
    OTHER: "Other"
});

export const VendorRedirects = Object.freeze({
    OPPORTUNITY: 'Opportunity',
    OPPORTUNITY_COMMENTS: 'Opportunity Comment',
    OBLIGATION: 'Obligation',
    RECURRING_SERVICE: 'Recurring Service',
    MY_SCHEDULE: 'My Schedule'

});

export const ClientRedirects = Object.freeze({
    REQUEST: 'Request',
    REQUEST_COMMENTS: 'Request Comment',
    OBLIGATION: 'Obligation',
    DASHBOARD: 'Dashboard',
    RECURRING_SERVICE: 'Recurring Service',
    MY_SCHEDULE: 'My Schedule'

});

export const PayableItemGroupJobType = Object.freeze({
    RECURRING: "Recurring",
    ONE_TIME: "One Time",
    WALKTHROUGH: "Walkthrough",
    MISCELLANEOUS: "Miscellaneous"
});

export const ObligationJobType = Object.freeze({
    RECURRING: "Recurring Job",
    ONE_TIME: "One Time Job",
    WALKTHROUGH: "Walkthrough",
});

//Available field types for forms
export const FormFieldType = Object.freeze({
    TEXT: 'text',
    SELECT: 'select',
    CHECKBOX: 'checkbox',
    DATE_PICKER: 'date picker',
    RANGE_PICKER: 'range picker',
    ITEM_LIST: 'item list',
    ELEMENT: 'element',
    FILE_UPLOAD: 'file upload',
    MULTISELECT: 'multiselect',
    RATING: 'rating'
});


//Available subtypes for individual form fields
export const TextFieldSubtype = Object.freeze({
    DOLLARS: 'dollars',
    NUMBER: 'number',
    PASSWORD: 'password',
    EMAIL: 'email',
    SEARCH: 'search',
    MESSAGE: 'message'
});

export const AutoCapitalizeType = Object.freeze({
    CHARACTERS: 'characters',
    NONE: 'none',
    SENTENCES: 'sentences',
    WORDS: 'words'
});

export const TextFieldIconPosition = Object.freeze({
    RIGHT: 'right',
    LEFT: 'left'
});

export const SelectFieldSubtype = Object.freeze({
    BUTTON_GROUP: 'button group',
    DROPDOWN: 'dropdown',
    ELEMENT_SELECT: 'element select',
    RADIO_BUTTONS: 'radio buttons',
    SEARCH_LIST: 'search list'
});

export const DatePickerSubtype = Object.freeze({
    CALENDAR: 'calendar',
    SPINNER: 'spinner'
});

export const ScheduleStatusType = Object.freeze({
    NEEDS_VENDOR: 'NEEDS_VENDOR',
    NEEDS_CLIENT: 'NEEDS_CLIENT',
    ACCEPTED: 'ACCEPTED',
    CANCELED: 'CANCELED',
    DECLINED: 'DECLINED',
});

//User types
export const UserType = Object.freeze({
    CLIENT: 'Client',
    VENDOR: 'Vendor',
    WORKSMITH: 'Worksmith'
});

export const FirebaseUserType = Object.freeze({
    CLIENT_LOCAL_MANAGER: 'Client - Location Manager',
    CLIENT_REGIONAL_MANAGER: 'Client - Regional Manager',
    CLIENT_ADMIN: 'Client - Administrator',
    VENDOR: 'Vendor',
    WORKSMITH: 'Worksmith'
});

//Comment types
export const CommentType = Object.freeze({
    OPPORTUNITY: 'job opportunity',
    REQUEST: 'request'
});

export const JobCancellationType = Object.freeze({
    SINGLE: 'single job',
    RECURRING_SERVICE: 'recurring service'
});

//Obligation statuses
export const ObligationStatus = Object.freeze({
    PENDING: 'pending',
    CANCELED:'canceled',
    COMPLETED:'completed'
});

export const ChangeRequestStatus = Object.freeze({
    NEEDS_CLIENT_INPUT: 'needs client input',
    NEEDS_VENDOR_INPUT:'needs vendor input',
    CANCELED:'canceled',
    ACCEPTED: 'accepted'
});


//Firebase event enums
export const FirebaseEventType = Object.freeze({
    BID_ACCEPTED: 'bid_accepted',
    BID_ACCEPTED_AND_SCHEDULED: 'bid_accepted_and_scheduled',
    BID_CANCELED: 'bid_canceled',
    BID_DECLINED: 'bid_declined',
    BID_LATER: 'bid_later',
    BID_NOW: 'bid_now',
    BID_SCHEDULE_ACCEPTED: 'bid_schedule_accepted',
    BID_SUBMITTED: 'bid_submitted',
    CHANGE_REQUEST_ACCEPTED: 'change_request_accepted',
    CHANGE_REQUEST_CANCELED: 'change_request_canceled',
    CHANGE_REQUEST_COUNTERED: 'change_request_countered',
    CHANGE_REQUEST_REQUESTED: 'change_request_requested',
    CLIENT_FEEDBACK_ADDED: 'client_feedback_added',
    CORPORATE_REVIEW_APPROVED: 'corporate_review_approved',
    CORPORATE_REVIEW_DECLINED: 'corporate_review_declined',
    JOB_COMPLETED: 'job_completed',
    LOGGED_IN: 'logged_in',
    LOGGED_OUT: 'logged_out',
    OBLIGATION_ATTACHMENT_ADDED: 'obligation_attachment_added',
    OPPORTUNITY_COMMENTS_READ: 'opportunity_comments_read',
    OPPORTUNITY_COMMENT_ADDED: 'opportunity_comment_added',
    OPPORTUNITY_DECLINED: 'opportunity_declined',
    PASSWORD_RESET_REQUESTED: 'password_reset_requested',
    PROPOSAL_ACCEPTED: 'proposal_accepted',
    PROPOSAL_ACCEPTED_AND_SCHEDULED: 'proposal_accepted_and_scheduled',
    RECURRING_SERVICE_CANCELLED: 'recurring_service_cancelled',
    REQUEST_ATTACHMENT_ADDED: 'request_attachment_added',
    REQUEST_CANCELLED: 'request_cancelled',
    REQUEST_COMMENT_ADDED: 'request_comment_added',
    REQUEST_COMMENTS_READ: 'request_comments_read',
    REQUEST_SUBMITTED: 'request_submitted',
    SCHEDULE_COMMENT_ADDED: 'schedule_comment_added',
    SCHEDULE_COUNTER_OFFER_MADE: 'schedule_counter_offer_made',
    SERVICE_ERROR: 'service_error',
    SINGLE_JOB_CANCELLED: 'single_job_cancelled',
    SUPPORT_TICKET_SUBMITTED: 'support_ticket_submitted',
    WALKTHROUGH_ACCEPTED: 'walkthrough_accepted',
    WALKTHROUGH_ACCEPTED_AND_SCHEDULED: 'walkthrough_accepted_and_scheduled',
    WALKTHROUGH_CANCELED: 'walkthrough_canceled',
    WALKTHROUGH_DECLINED: 'walkthrough_declined',
    WALKTHROUGH_SCHEDULE_ACCEPTED: 'walkthrough_schedule_accepted',
    WALKTHROUGH_SUBMITTED: 'walkthrough_submitted'
});

export const FirebaseEventParameter = Object.freeze({
    SERVICE_ERROR: function(actionIdentifier, errorMessage) {
        return {
            method: actionIdentifier,
            value: errorMessage
        }
    }
});

//Native keyboard types
export const KeyboardType = Object.freeze({
    DEFAULT: 'default',
    NUMBER_PAD: 'number-pad',
    DECIMAL_PAD: 'decimal-pad',
    NUMERIC: 'numeric',
    EMAIL_ADDRESS: 'email-address',
    PHONE_PAD: 'phone-pad'
});


//Pointer event types (handles how views respond to touch events)
//For more info see https://facebook.github.io/react-native/docs/view#pointerevents
export const PointerEventType = Object.freeze({
    AUTO: 'auto',
    NONE: 'none',
    BOX_NONE: 'box-none',
    BOX_ONLY: 'box-only'
});


//Modal Animation types that affect how a native modal closes
export const ModalAnimationType = Object.freeze({
    SLIDE: 'slide',
    FADE: 'fade',
    NONE: 'none'
});


//Direction the SideMenu component comes from
export const MenuSideOption = Object.freeze({
    LEFT: 'left',
    RIGHT: 'right',
    BOTTOM: 'bottom',
    TOP: 'top'
});

//iOS only supports these minute intervals
export const DatePickerMinuteInterval = Object.freeze({
    ONE: 1,
    TWO: 2,
    THREE: 3,
    FOUR: 4,
    FIVE: 5,
    SIX: 6,
    TEN: 10,
    TWELVE: 12,
    FIFTEEN: 15,
    TWENTY: 20,
    THIRTY: 30
});

export const DatePickerMode = Object.freeze({
    DATE: 'date',
    TIME: 'time',
    DATETIME: 'datetime'
});

export const RecurrenceType = Object.freeze({
    DAILY: 'Daily',
    WEEKLY: 'Weekly',
    MONTHLY: 'Monthly'
});

//Can't believe our backend is set up with both this and RecurrenceType
export const RfpRecurrenceType = Object.freeze({
    DAY: "day",
    WEEK: "week",
    MONTH: "month"
});

export const RfpTimePreference = Object.freeze({
    NO_PREFERENCE: "No Preference",
    BEFORE_HOURS: "Before Business Hours",
    DURING_HOURS: "During Business Hours",
    AFTER_HOURS: "After Business Hours"
});

export const WalkthroughPreference = Object.freeze({
    REQUIRED: "Walkthrough Required",
    PROHIBITED: "Walkthrough Prohibited",
    OPTIONAL: "Walkthrough Optional"
});

export const ScheduleType = Object.freeze({
    ONE_TIME: 'one-time',
    RECURRING: 'recurring'
});

//Strings to be used with moment objects for things like adding/subtracting intervals of time (ex. moment().add(4, MomentShorthand.DAYS))
export const MomentShorthand = Object.freeze({
    MILLISECONDS: 'ms',
    SECONDS: 's',
    MINUTES: 'm',
    HOURS: 'h',
    DAYS: 'd',
    WEEKS: 'w',
    MONTHS: 'M',
    QUARTERS: 'Q',
    YEARS: 'y'
});

export const MomentFormat = Object.freeze({
    MonthDayYear: 'MM-DD-YYYY',                         //EX: 12-25-2018
    MonthDayYearSlash: 'MM/DD/YYYY',                    //EX: 12/25/2018
    ISODate: 'YYYY-MM-DD',                              //EX: 2018-01-11
    MonthDay: 'MMM Do',                                 //EX: Sep 19th
    Dom: 'Do',                                          //EX: 21st
    FullDow: 'dddd',                                    //EX: Thursday
    DowMonthDayYear: 'ddd, MMM D YYYY',                 //EX: Thu, May 1 2018
    DowMonthDom: 'ddd, MMM Do',                         //EX: Thu, Nov 1st
    FullDowFullMonthDom: 'dddd, MMMM Do',               //EX: Thursday, November 1st
    DateTime: 'MM/DD/YY h:mmA',                         //EX: 09/18/18 12:47PM
    FullDayFullMonthDomYear: 'dddd, MMMM Do YYYY',      //EX: Friday, December 28th 2018
    FullDateTime: 'MMMM Do YYYY h:mm a',                //EX: December 28th 2018 3:46 pm
    MonthDomYear: 'MMM D, YYYY',                        //EX: Jan 1, 2019
    FullMonthYear: 'MMMM YYYY',                         //EX: January 2019
    FullMonthYearWithoutSpace: 'MMMMYYYY',              //EX: January2019
    FullMonth: 'MMMM',                                  //EX: January
    HoursMinutesSeconds: 'HH:mm:ss',                    //EX: 14:23:14 (can be used when backend needs a LocalTime)
    HoursMinutes: 'HH:mm:00',                           //EX: 14:23:00
    StandardTime: 'h:mm A',                             //EX: 1:32 PM
    Time: 'LT'
});

export const AsyncStorageKeys = Object.freeze({
    AUTH_TOKEN: "@AuthToken:key",
    REFRESH_TOKEN: "@RefreshToken:key",
    USER_ID: "@UserId:key",
    USER: "@User:key"
});

//Service call Types
export const RequestMethod = Object.freeze({
    DELETE: 'DELETE',
    GET: 'GET',
    HEAD: 'HEAD',
    OPTIONS: 'OPTIONS',
    PATCH: 'PATCH',
    POST: 'POST',
    PUT: 'PUT',
});

//CSS Enum representations
export const JustifyContent = Object.freeze({
    FLEX_START: 'flex-start',
    CENTER: 'center',
    FLEX_END: 'flex-end',
    SPACE_AROUND: 'space-around',
    SPACE_BETWEEN: 'space-between',
    SPACE_EVENLY: 'space-evenly'
});

export const AlignItems = Object.freeze({
    FLEX_START: 'flex-start',
    CENTER: 'center',
    FLEX_END: 'flex-end',
    STRETCH: 'stretch'
});

export const TextAlign = Object.freeze({
    CENTER: 'center',
    INHERIT: 'inherit',
    JUSTIFY: 'justify',
    LEFT: 'left',
    RIGHT: 'right',
});

export const TextDecoration = Object.freeze({
    NONE: 'none',
    UNDERLINE: 'underline',
    LINE_THROUGH: 'line-through',
    UNDERLINE_LINE_THROUGH: 'underline line-through'
});

export const OverflowOption = Object.freeze({
    AUTO: 'auto',
    HIDDEN: 'hidden',
    SCROLL: 'scroll',
    VISIBLE: 'visible'
});

export const PositionType = Object.freeze({
    ABSOLUTE: 'absolute',
    RELATIVE: 'relative'
});

export const ImageResizeMode = Object.freeze({
    CENTER: 'center',
    CONTAIN: 'contain',
    COVER: 'cover',
    REPEAT: 'repeat',
    STRETCH: 'stretch'
});

export const FlexDirection = Object.freeze({
    COLUMN: 'column',
    COLUMN_REVERSE: 'column-reverse',
    ROW: 'row',
    ROW_REVERSE: 'row-reverse'
});

export const Headers = Object.freeze({
    CONTENT_TYPE_JSON: { "Content-Type" : "application/json" },
    MULTIPART_FORM_DATA: {
        "Content-Type": "multipart/form-data",
        "transfer-encoding": "chunked"
    }
});

export const DeviceHeaderKeys = Object.freeze({
    MANUFACTURER: "Manufacturer",
    MODEL: "Model",
    OPERATING_SYSTEM: "Operating-System",
    OS_VERSION: "Os-Version",
    PRODUCT: "Product"
});

export const ChangeRequestType = Object.freeze({
    TIME: "time"
});

export const OpportunityState = Object.freeze({
    NEW: "New",
    MESSAGE_SENT: "Message Sent",
    WALKTHROUGH_REQUEST_SUBMITTED: "Walkthrough Request Submitted",
    WALKTHROUGH_DECLINED: "Walkthrough Declined",
    WALKTHROUGH_ACCEPTED: "Walkthrough Accepted, Confirming Scheduling",
    NEW_WALKTHROUGH_SCHEDULE_PROPOSED_BY_CLIENT: "New WT Schedule Proposed",
    NEW_WALKTHROUGH_SCHEDULE_SUBMITTED_BY_VENDOR: "New WT Schedule Submitted",
    WALKTHROUGH_SCHEDULED: "Walkthrough Scheduled",
    WALKTHROUGH_COMPLETED: "Walkthrough Completed",
    BID_SUBMITTED: "Bid Submitted",
    BID_DECLINED: "Bid Declined",
    BID_ACCEPTED: "Bid Accepted, Confirming Scheduling",
    NEW_SCHEDULE_PROPOSED_BY_CLIENT: "New Schedule Proposed",
    NEW_SCHEDULE_SUBMITTED_BY_VENDOR: "New Schedule Submitted",
    SERVICE_SCHEDULED: "Service Scheduled",
    CLOSED: "Closed",
    CANCELED: "Canceled",
    COMPLETED: "Completed"
});

export const OpportunityAction = Object.freeze({
    DECLINE_OPPORTUNITY: {
        key: "DECLINE_OPPORTUNITY",
        name: "Decline Opp"
    },
    SUBMIT_WALKTHROUGH: {
        key: "SUBMIT_WALKTHROUGH",
        name: "Submit WT"
    },
    CANCEL_WALKTHROUGH: {
        key: "CANCEL_WALKTHROUGH",
        name: "Cancel WT"
    },
    COMPLETE_WALKTHROUGH: {
        key: "COMPLETE_WALKTHROUGH",
        name: "Complete WT"
    },
    RESCHEDULE_WALKTHROUGH: {
        key: "RESCHEDULE_WALKTHROUGH",
        name: "Reschedule WT"
    },
    SUBMIT_BID: {
        key: "SUBMIT_BID",
        name: "Submit Bid"
    },
    CANCEL_BID: {
        key: "CANCEL_BID",
        name: "Cancel Bid"
    },
    COMPLETE_JOB: {
        key: "COMPLETE_JOB",
        name: "Complete Job"
    },
    RESCHEDULE_JOB: {
        key: "RESCHEDULE_JOB",
        name: "Reschedule Job"
    },
    REVIEW_CHANGE_REQUEST: {
        key: "REVIEW_CHANGE_REQUEST",
        name: "Review Schedule Change"
    },
    RESCHEDULE_WALKTHROUGH_REQUEST: {
        key: "RESCHEDULE_WALKTHROUGH_REQUEST",
        name: "Reschedule Walkthrough Request"
    },
    RESCHEDULE_BID_REQUEST: {
        key: "RESCHEDULE_BID_REQUEST",
        name: "Reschedule Bid Request"
    },
    RESCHEDULE_CHANGE_REQUEST: {
        key: "RESCHEDULE_CHANGE_REQUEST",
        name: "Reschedule Change Request"
    }
});

export const CalendarView = Object.freeze({
    WEEK: 'week',
    MONTH: 'month'
});

export const KeyboardEvent = Object.freeze({
    KEYBOARD_WILL_SHOW: 'keyboardWillShow',
    KEYBOARD_DID_SHOW: 'keyboardDidShow',
    KEYBOARD_WILL_HIDE: 'keyboardWillHide',
    KEYBOARD_DID_HIDE: 'keyboardDidHide',
    KEYBOARD_WILL_CHANGE_FRAME: 'keyboardWillChangeFrame',
    KEYBOARD_DID_CHANGE_FRAME: 'keyboardDidChangeFrame'
});

export const ServiceLineCategory = Object.freeze({
    FACILITIES_MAINTENANCE: "Facilities Maintenance",
    DRY_CLEANING_AND_LAUNDRY: "Dry Cleaning & Laundry",
    EVENTS:"Events",
    ENVIRONMENT_SETUP:"Environment Setup"
});

export const AutoAcceptWalkthroughsDuringBusinessHours = Object.freeze({
    ALWAYS: "ALWAYS",
    SOMETIMES: "SOMETIMES",
    NEVER: "NEVER"
});

export const JavascriptType = Object.freeze({
    BOOLEAN: 'boolean',
    FUNCTION: 'function',
    NUMBER: 'number',
    OBJECT: 'object',
    STRING: 'string',
    SYMBOL: 'symbol',
    UNDEFINED: 'undefined'
});

export const NeedsAttentionStrings = Object.freeze({
    CORPORATE_REVIEW: (plural) => plural ?  'Requests in corporate review' : 'Request in corporate review',
    PENDING_BIDS: (plural) => plural ? 'Requests with pending bids' : 'Request with pending bids',
    UNREAD_MESSAGES: (plural) => plural ? 'Requests with unread messages' : 'Request with unread messages',
    EMERGENCY: (plural) => plural ? 'Emergency Requests' : 'Emergency Request',
    SCHEDULE_CHANGE: (plural) => plural ? 'Jobs to Reschedule' : 'Job to Reschedule',
    JOBS_TO_SCHEDULE: (plural) => plural ? 'Jobs to Schedule' : 'Job to Schedule',
    RECURRING_SCHEDULE_CHANGES: (plural) => plural ? "Recurring schedule changes" : "Recurring schedule change",
    WALKTHROUGHS_TO_SCHEDULE: (plural) => plural ? 'Requests with walkthroughs to schedule' : 'Request with walkthroughs to schedule',
    WALKTHROUGH_SUBMITTED: (plural) => plural ? 'Requests with walkthrough submitted' : 'Request with walkthrough submitted',
    COMPLETED_JOBS_TO_RATE: (plural) => plural ? 'Completed jobs to rate and review' : 'Completed job to rate and review'
});

export const NewRequestStatus = Object.freeze({
    CORPORATE_REVIEW: "corporate review",
    MARKET: "market",
    SCHEDULING: "scheduling",
    CORPORATE_BID_REVIEW: "corporate bid review",
    SCHEDULED: "scheduled",
    COMPLETED: "completed",
    CANCELED: "canceled"
});

export const CancellationReasonType = Object.freeze({
    REQUEST: 'REQUEST'
});

export const RfpMarket = Object.freeze({
    OPEN_NETWORK: "OPEN_NETWORK",
    PREFERRED: "PREFERRED",
    WARRANTY: "WARRANTY",
    NONE: "NONE"
});

export const FieldVisibilityConstant = Object.freeze({
    ANY_VALUE: 'any value'
});

export const RepeatBy = Object.freeze({
    DAY_OF_WEEK: "dayOfWeek",
    DAY_OF_MONTH: "dayOfMonth"
});

export const FeedbackRequestType = Object.freeze({
    SINGLE_JOB: "single job",
    RECURRING_SERVICE: "recurring service"
});

export const AppStateEvent = Object.freeze({
    ACTIVE: 'active',
    BACKGROUND: 'background',
    INACTIVE: 'inactive'
});
