import {Linking, Platform, Alert, ActionSheetIOS} from 'react-native';
import {canOpenUrl} from "../index";

const AppleMaps = Object.freeze({
    title: "Maps",
    url: 'http://maps.apple.com/'
});

const GoogleMaps = Object.freeze({
    title: "Google Maps",
    iOSurl: 'comgooglemaps://',
    androidUrl: 'https://www.google.com/maps/',
});

const Waze = Object.freeze({
    title: "Waze",
    url: 'waze://',
});


export const openMapsWithAddress = (address) => {

    Promise.all([
                canOpenUrl(AppleMaps.url),
                canOpenUrl(Platform.OS === 'ios' ? GoogleMaps.iOSurl : GoogleMaps.androidUrl),
                canOpenUrl(Waze.url)
                ]).then(([canOpenAppleMaps, canOpenGoogleMaps, canOpenWaze]) => {

                    let mapOptions = [];
                    if (Platform.OS === 'ios') {
                        let mapCallbacks = [];

                        if (canOpenAppleMaps) {
                            mapOptions.push('Open in Maps');
                            mapCallbacks.push(() => Linking.openURL(getAppleMapsUrl(address)))
                        }

                        if (canOpenGoogleMaps) {
                            mapOptions.push('Open in Google Maps');
                            mapCallbacks.push(() => Linking.openURL(getGoogleMapsUrl(address)))
                        }

                        if (canOpenWaze) {

                            mapOptions.push('Open in Waze');
                            mapCallbacks.push(() => Linking.openURL(getWazeUrl(address)))
                        }

                        mapOptions.push('Cancel');

                        ActionSheetIOS.showActionSheetWithOptions({
                            title: "Which map application would you like to use?",
                            options: mapOptions,
                            cancelButtonIndex: mapOptions.length - 1
                        }, (buttonIndex) => {
                            if (buttonIndex === mapOptions.length - 1) {
                                return null;
                            }
                            return mapCallbacks[buttonIndex].apply();
                        })

                    } else {
                        mapOptions.push({ text: "Cancel", onPress: () => null, style: 'cancel' });

                        if (canOpenGoogleMaps) {
                            mapOptions.push({
                                text: GoogleMaps.title,
                                onPress: () => Linking.openURL(getGoogleMapsUrl(address)),
                                style: 'cancel'
                            });
                        }

                        if (canOpenWaze) {
                            mapOptions.push({
                                text: Waze.title,
                                onPress: () => Linking.openURL(getWazeUrl(address)),
                                style: 'cancel'
                            });
                        }

                        return Alert.alert("Which map application would you like to use?", null, mapOptions)
                    }
    })
};

/* These functions take the Address Read Object that we have on the backend as a parameter */

const getGoogleMapsUrl = (address) => {
    let encodedParams = getEncodedQueryParam(address);

    if (Platform.OS === 'ios') {
        return GoogleMaps.iOSurl + "?q=" + encodedParams;
    } else {
        return GoogleMaps.androidUrl + "search/?api=1&query=" + encodedParams;
    }
};

const getAppleMapsUrl = (address) => {
    return AppleMaps.url + "?q=" + getEncodedQueryParam(address);
};

const getWazeUrl = (address) => {
    return Waze.url + "?q=" + getEncodedQueryParam(address);
};

const getEncodedQueryParam = (address) => {
    return encodeURIComponent(
        address.addressLineOne +  " "
            + address.addressLineTwo + ' '
            + address.city + ", "
            + address.state + ' '
            + address.zip);
};

/* */
