import moment from 'moment';
import {MomentFormat, ScheduleType} from "./Enums";
import {ConvertDaysOfWeekToListOfNumbers} from "../index";


// This function will take schedules that are created from our scheduling forms, ProposalSchedulingFormOptions for example
export const formatScheduleForBackend = (schedule, scheduleType) => {
    let daysOfWeek = [];
    let isRecurring = scheduleType === ScheduleType.RECURRING;
    if (isRecurring) {
        daysOfWeek = ConvertDaysOfWeekToListOfNumbers(schedule.sunday, schedule.monday, schedule.tuesday, schedule.wednesday, schedule.thursday, schedule.friday, schedule.saturday).reduce((daysOfWeek, dayNumber) => {
            daysOfWeek.push({
                dayOfWeek: dayNumber
            });

            return daysOfWeek;
        }, [])
    }

    return ({
        date: schedule.date.format(MomentFormat.ISODate),
        type: isRecurring ? ScheduleType.RECURRING : ScheduleType.ONE_TIME,
        arrivalStartTime: moment(schedule.arrivalWindow.start, MomentFormat.StandardTime).format(MomentFormat.HoursMinutes),
        arrivalEndTime: moment(schedule.arrivalWindow.end, MomentFormat.StandardTime).format(MomentFormat.HoursMinutes),
        recurrenceType: isRecurring ? schedule.recurrenceType : null,
        repeatEvery: isRecurring ? schedule.repeatEvery : null,
        daysOfWeek: daysOfWeek,
        dayOfMonth: scheduleType ? schedule.repeatBy === 'dayOfMonth' : null
    });
};

export const formatScheduleListForBackend = (schedules, scheduleType) => {
    return schedules.reduce((schedules, schedule) => {
        schedules.push(formatScheduleForBackend(schedule, scheduleType));
        return schedules;
    }, []);
};

export const isExpired = (schedule) => {
    let time = moment(schedule.arrivalStartTime, MomentFormat.HoursMinutesSeconds);
    return schedule.arrivalStartTime ?
        // compare to current time
        (moment(schedule.date).hour(time.hour()).minute(time.minute())).isBefore(moment())
        :
        // compare to the start of today
        (moment(schedule.date)).isBefore(moment().startOf('day'));
};

